#ifndef LW_ENGINE_INCLUDED
#define LW_ENGINE_INCLUDED

#define LW_MAX_HIGH_RELEVENT_RESULTS 1000
#define LW_MAX_MEDIUM_IRRELEVENT_RESULTS 1000
#define LW_MAX_LOW_IRRELEVENT_RESULTS    1000

void lw_searchitem_start_search (LwSearchItem*, gboolean, gboolean);

#endif
