#ifndef LW_LIBWAEI_INCLUDED
#define LW_LIBWAEI_INCLUDED

#ifdef HAVE_CONFIG_H
#include "../../../../config.h"
#endif
#include "gettext.h"

#include <libwaei/regex.h>
#include <libwaei/utilities.h>
#include <libwaei/io.h>
#include <libwaei/preferences.h>
#include <libwaei/dict.h>
#include <libwaei/dictinfo.h>
#include <libwaei/dictinfolist.h>
#include <libwaei/dictinst.h>
#include <libwaei/dictinstlist.h>
#include <libwaei/resultline.h>
#include <libwaei/queryline.h>
#include <libwaei/searchitem.h>
#include <libwaei/engine.h>
#include <libwaei/history.h>


#endif
